package com.xkrs.dao;

import com.xkrs.model.entity.DataSource;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 16:41
 */
@Component
public interface DataSourceDao extends JpaRepository<DataSource,Long>, JpaSpecificationExecutor<DataSource> {

    /**
     * 查询测量数据信息
     * @param dataModelNumber
     * @param dataBatchNumber
     * @param dataMachineCode
     * @param productNumber
     * @return
     */
    @Query(value = "select ds.data_model_number datamodelnumber, ds.data_batch_number databatchnumber, " +
            "ds.data_machine_code datamachinecode, ds.product_number productnumber, ds.material material, dd.dict_chinese_name chinesename, " +
            "ds.data_name dataname,ds.numerical_value numericalvalue " +
            "from data_dict dd,data_source ds where ds.data_name = dd.dict_english_name and " +
            "ds.data_model_number = :dataModelNumber and ds.data_batch_number = :dataBatchNumber and " +
            "ds.data_machine_code = :dataMachineCode and ds.product_number = :productNumber",nativeQuery = true)
    List<Map<String,String>> selectDataSource(String dataModelNumber, String dataBatchNumber, String dataMachineCode, String productNumber);

    /**
     * 查询测量信息变量和测量值，用于模板的导入
     * @param dataModelNumber
     * @param dataBatchNumber
     * @param dataMachineCode
     * @param productNumber
     * @return
     */
    @Query(value = "select data_name dataname,numerical_value numericalvalue from data_source " +
            "where data_model_number = :dataModelNumber and data_batch_number = :dataBatchNumber " +
            "and data_machine_code = :dataMachineCode and product_number = :productNumber",nativeQuery = true)
    List<Map<String,String>> selectDataNameAndData(String dataModelNumber, String dataBatchNumber, String dataMachineCode, String productNumber);

    /**
     * 通过英文变量查询信息
     * @param dataname
     * @return
     */
    DataSource findByDataName(String dataname);

    /**
     * 查询全部的测量信息
     * @return
     */
    @Query(value = "select ds.data_model_number datamodelnumber, ds.data_batch_number databatchnumber, " +
            "ds.data_machine_code datamachinecode, ds.product_number productnumber, ds.material material, dd.dict_chinese_name chinesename," +
            "ds.data_name dataname,ds.numerical_value numericalvalue from data_dict dd,data_source ds " +
            "where ds.data_name = dd.dict_english_name",nativeQuery = true)
    List<Map<String,String>> selectAllSource();
}
